service daemon/squid {
	need = system/initial system/hostname system/network
	nice = +5

	start {
		# Sanity check
		[ -f /etc/squid/squid.conf ] || exit 0

		# Source function library
		. /etc/rc.d/init.d/functions

		# Get service config
		[ -f /etc/sysconfig/squid ] && . /etc/sysconfig/squid

		msg_starting Squid
		ulimit -n 8192
		daemon squid $SQUID_OPTS
		RETVAL=$?

		exit $RETVAL
	}

	stop {
		# Sanity check
		[ -f /etc/squid/squid.conf ] || exit 0

		# Source function library
		. /etc/rc.d/init.d/functions

		# Get service config
		[ -f /etc/sysconfig/squid ] && . /etc/sysconfig/squid

		msg_stopping Squid

		if [ -f /var/run/squid.pid ]; then
			PID=$(filter_chroot `cat /var/run/squid.pid`)
			if [ -z "$PID" ]; then
				PID=0
			fi
		else
			PID=0
		fi
		killproc squid
		RETVAL=$?
		if [ ! $PID -eq 0 ]; then
			show "Waiting for Squid to stop"
			busy
			while ps -U squid -o user | grep -q ^squid
			do
				sleep 1
			done
			ok
		fi
		rm -f /var/lock/subsys/squid >/dev/null 2>&1

		exit $RETVAL
	}
}
